kicad_netlist_reader
====================

KiCad python module for interpreting generic netlists which can be
used to generate Bills of materials, etc. Simple repackaging of the
original Kicad source file.

Authors:

    Jean-Pierre Charras jean-pierre.charras@gipsa-lab.inpg.fr

Package Maintainers:

    Peter Polidoro <peter@polidoro.io>

License:

    GPL
